@@ -75,6 +75,19 @@ def get_smart_token(platform: str) -> str:
     return r['token']
 
 
+def get_integration_info(
+    platform: str, integration_id: int, token: Optional[str] = None
+) -> dict:
+    if not token:
+        token = get_smart_token(platform)
+    config_url = f'{DASHBOARD_URL}api/get_config_url/?platform_id={platform}'
+    dash_response = requests.get(f'{config_url}?platform_id={platform}').json()
+    headers = {"Authorization": token}
+    integration_url = f'{dash_response["config_url"]}{integration_id}/'
+    integration = requests.get(integration_url, headers=headers).json()
+    return integration
+
+
 def delete_file(filename: str):
     os.remove(filename)
 
